/*
 * Created on Jun 24, 2004
 *
 * This file is licensed under the terms of the Artistic License as
 * described at http://www.opensource.org/licenses/artistic-license.php
 *
 * Use and/or redistribution under the terms of the GNU Lesser GPL
 * (http://www.opensource.org/licenses/lgpl-license.php) is also allowed.
 */
package com.blackperl.Perl;

import junit.framework.TestCase;

import java.util.Locale;

/**
 * JUnit test class for <code>Ucfirst</code>.
 * 
 * Exercises the various public methods of the <code>Ucfirst</code> class.
 * 
 * @author rjray
 * @version $Id: UcfirstTest.java,v 1.3 2004/07/20 08:31:18 rjray Exp $
 */
public class UcfirstTest extends TestCase
{
    private static final String in  = "fred";
    private static final String out = "Fred";
    
    /**
     * Constructor for UcfirstTest.
     * @param name
     */
    public UcfirstTest(String name)
    {
        super(name);
    }

    /*
     * Test the instance() method to ensure that it always returns the same
     * object.
     */
    final public void testInstance()
    {
        // Call instance() twice. See if they match.
        Ucfirst c1 = Ucfirst.instance();
        Ucfirst c2 = Ucfirst.instance();
        
        assertEquals("Test two calls to instance() for equality", c1, c2);
    }

    /*
     * Test for String ucfirst(String)
     */
    final public void testUcfirstString()
    {
        assertEquals("Test basic String signature",
            Ucfirst.ucfirst(in), out);
    }

    /*
     * Test for String ucfirst(String, Locale)
     */
    final public void testUcfirstStringLocale()
    {
        // This is kind of a cheat, using the "US" locale...
        assertEquals("Test basic String signature",
            Ucfirst.ucfirst(in, Locale.US), out);
    }

    /*
     * Test for String ucfirst(StringBuffer)
     */
    final public void testUcfirstStringBuffer()
    {
        StringBuffer buffer = new StringBuffer(10);
        buffer.append(in);
        
        String res = Ucfirst.ucfirst(buffer);
        
        assertEquals("Test basic StringBuffer signature (buffer compare)",
            buffer.toString(), out);
        assertEquals("Test basic StringBuffer signature (result compare)",
            res, out);
    }

    /*
     * Test for String ucfirst(StringBuffer, Locale)
     */
    final public void testUcfirstStringBufferLocale()
    {
        // This is kind of a cheat, using the "US" locale...
        StringBuffer buffer = new StringBuffer(10);
        buffer.append(in);
        
        String res = Ucfirst.ucfirst(buffer, Locale.US);
        
        assertEquals("Test basic StringBuffer signature (buffer compare)",
            buffer.toString(), out);
        assertEquals("Test basic StringBuffer signature (result compare)",
            res, out);
    }
}
